# safewise-common


Common files shared among SafeWISE repositories.

This repo is meant to be included as submodule to others using:

```
git submodule add https://github.com/trezor/trezor-common.git trezor-common
```
